@@ -1,26 +1,9 @@
-/*****************************************************************************
- * Copyright 2010 (c) Miquel Canes Gonzalez <miquelcanes@gmail.com>          *
- * Copyright 2012 (c) Sven Brauch <svenbrauch@googlemail.com>                *
- *                                                                           *
- * Permission is hereby granted, free of charge, to any person obtaining     *
- * a copy of this software and associated documentation files (the           *
- * "Software"), to deal in the Software without restriction, including       *
- * without limitation the rights to use, copy, modify, merge, publish,       *
- * distribute, sublicense, and/or sell copies of the Software, and to        *
- * permit persons to whom the Software is furnished to do so, subject to     *
- * the following conditions:                                                 *
- *                                                                           *
- * The above copyright notice and this permission notice shall be            *
- * included in all copies or substantial portions of the Software.           *
- *                                                                           *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,           *
- * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF        *
- * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND                     *
- * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE    *
- * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION    *
- * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION     *
- * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.           *
- *****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Miquel Canes Gonzalez <miquelcanes@gmail.com>
+    SPDX-FileCopyrightText: 2012 Sven Brauch <svenbrauch@googlemail.com>
+
+    SPDX-License-Identifier: MIT
+*/
 
 #include <QDebug>
 #include "duchaindebug.h"
@@ -162,7 +145,7 @@ ReferencedTopDUContext PyDUChainTest::parse(const QString& code)
     TestFile* testfile = new TestFile(code + "\n", "py", nullptr, testDir.absolutePath().append("/"));
     createdFiles << testfile;
 
-    testfile->parse((TopDUContext::Features) (TopDUContext::ForceUpdate | TopDUContext::AST) );
+    testfile->parse(TopDUContext::ForceUpdate | TopDUContext::AST);
     testfile->waitForParsed(2000);
     
     if ( testfile->isReady() ) {
@@ -255,6 +238,7 @@ void PyDUChainTest::testCrashes() {
 void PyDUChainTest::testCrashes_data() {
     QTest::addColumn<QString>("code");
     
+    QTest::newRow("composite_slice") << "A = M[1:3, 3]";
     QTest::newRow("unicode_char") << "a = \"í\"";
     QTest::newRow("unicode escape char") << "print(\"\\xe9\")";
     QTest::newRow("augassign") << "a = 3\na += 5";
